@@ -40,7 +40,7 @@ def humanized_name(thing):
 def format_assertion_msg(assertion_clause, *args):
     raw_msg = 'Expected topic({{0!r}}) {assertion_clause}'
     raw_msg = raw_msg.format(assertion_clause=assertion_clause)
-    if len(args) is 2:
+    if len(args) == 2:
         raw_msg += ' {1!r}'
     return raw_msg
 
@@ -57,20 +57,22 @@ class AssertionsMap(dict):
     '''A simple dict with a dash of logging.'''
 
     def __getitem__(self, k):
-        log.debug('fetching assertion: {name!r}'.format(name=k))
+        # log.debug('fetching assertion: {name!r}'.format(name=k))
         return super(AssertionsMap, self).__getitem__(k)
 
     def __setitem__(self, k, v):
         _keys = self.keys()
-        if k not in _keys:
-            log.debug('registering assertion: {name!r}, with function: {func!r}'.format(name=k, func=v))
-        elif self[k] is not v:  # existing key with new assertion function
-            log.debug('re-registering assertion: {name!r}, with new function: {func!r}'.format(name=k, func=v))
-        elif self[k] is v:  # same key, same function
+        # commented due to noise in tests
+        # if k not in _keys:
+            # log.debug('registering assertion: {name!r}, with function: {func!r}'.format(name=k, func=v))
+        # elif self[k] is not v:  # existing key with new assertion function
+            # log.debug('re-registering assertion: {name!r}, with new function: {func!r}'.format(name=k, func=v))
+        # elif self[k] is v:  # same key, same function
+            # return
+        if k in _keys and self[k] is v:  # same key, same function
             return
         return super(AssertionsMap, self).__setitem__(k, v)
 
     def __delitem__(self, k):
-        log.debug('deleting assertion: {name!r}'.format(name=k))
+        # log.debug('deleting assertion: {name!r}'.format(name=k))
         return super(AssertionsMap, self).__delitem__(k)
-
